@@ -133,7 +133,7 @@ def setup(settings_path=None, **settings_patches):
         print section_title('Create global settings')
         global_uwsgi_ini_template_path = os.path.join(BEANSTALK_ROOT_PATH, 'static/global_uwsgi.ini')
         with hide('everything'):
-            uid = local('id -u beanstalk', capture=True)
+            uid = local('id -u apache', capture=True)
         global_uwsgi_ini_content = render_file(global_uwsgi_ini_template_path, beanstalk_settings, BEANSTALK_UID=uid)
         with open('/etc/beanstalk/uwsgi.ini', 'w') as f:
             f.write(global_uwsgi_ini_content)
@@ -160,7 +160,7 @@ def setup(settings_path=None, **settings_patches):
     #    'Match Group beanstalk',
     #    '       ForceCommand /usr/bin/bs_ssh_entry',
     #]
-    #local(sed('$ a\\{command}'.format(command='\\n'.join(new_lines)), sshd_config))
+    #local(sed('$ a\\\n{command}'.format(command='\\n'.join(new_lines)), sshd_config))
     local(sed('/^AllowGroups wheel$/cAllowGroups wheel beanstalk', sshd_config))  # TODO: More general form
 
     # Apache conf
@@ -356,10 +356,13 @@ def install_app(project_name, settings_path=None, **settings_patches):
     # edit ini
     uwsgi_path = project_uwsgi_path(project_name)
     config = ConfigParser.ConfigParser()
+    # load in if it exists
     if os.path.exists(uwsgi_path):
         config.read(uwsgi_path)
+    # Create uwsgi section
     if not config.has_section('uwsgi'):
         config.add_section('uwsgi')
+    # Options that user can define
     optional_overrride_options = [
         ('master', True),
         ('enable-threads', True),
@@ -370,21 +373,28 @@ def install_app(project_name, settings_path=None, **settings_patches):
     for key, value in optional_overrride_options:
         if not config.has_option('uwsgi', key):
             config.set('uwsgi', key, value)
+    # Options that must be overriden by beanstalk
+    with hide('everything'):
+        uid = local('id -u apache', capture=True)
     must_override_options = [
         ('socket', '127.0.0.1:%d' % uwsgi_port),
         ('chdir', project_source_path(project_name)),
         ('home', project_venv_path(project_name)),
+        ('uid', uid),
+        ('logto', os.path.join(project_logs_path(project_name), 'uwsgi.log')),
     ]
     for key, value in must_override_options:
         config.set('uwsgi', key, value)
-    with hide('everything'):
-        uid = local('id -u beanstalk', capture=True)
-    config.set('uwsgi', 'uid', uid)
-    config.set('uwsgi', 'logto', os.path.join(project_logs_path(project_name), 'uwsgi.log'))
-    config.remove_option('uwsgi', 'http')
-    config.remove_option('uwsgi', 'https')
-    config.remove_option('uwsgi', 'http-proxy')
-    config.remove_option('uwsgi', 'http-to')
+    # Remove options
+    must_remove_options = [
+        'http',
+        'https',
+        'http-proxy',
+        'http-to',
+    ]
+    for key in must_remove_options:
+        config.remove_option('uwsgi', key)
+    # Write it back
     with open(uwsgi_path, 'wb') as f:
         config.write(f)
 
